==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.md <==
# AwsIoTThingTemperatureHumiditySensor


```text
aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')
```



| Illustration | AwsIoTThingTemperatureHumiditySensor | AwsIoTThingTemperatureHumiditySensorCard | AwsIoTThingTemperatureHumiditySensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.png) | ![illustration for AwsIoTThingTemperatureHumiditySensor](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.Local.png) | ![illustration for AwsIoTThingTemperatureHumiditySensorCard](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensorCard.Local.png) | ![illustration for AwsIoTThingTemperatureHumiditySensorGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensorGroup.Local.png) |




## AwsIoTThingTemperatureHumiditySensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensor
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensor('AwsIoTThingTemperatureHumiditySensor', 'Aws Io T Thing Temperature Humidity Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensor
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensor('AwsIoTThingTemperatureHumiditySensor', 'Aws Io T Thing Temperature Humidity Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingTemperatureHumiditySensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorCard('AwsIoTThingTemperatureHumiditySensorCard', 'Aws Io T Thing Temperature Humidity Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorCard('AwsIoTThingTemperatureHumiditySensorCard', 'Aws Io T Thing Temperature Humidity Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingTemperatureHumiditySensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorGroup('AwsIoTThingTemperatureHumiditySensorGroup', 'Aws Io T Thing Temperature Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorGroup('AwsIoTThingTemperatureHumiditySensorGroup', 'Aws Io T Thing Temperature Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.md <==
# AwsIoTThingTemperatureHumiditySensor


```text
aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')
```



| Illustration | AwsIoTThingTemperatureHumiditySensor | AwsIoTThingTemperatureHumiditySensorCard | AwsIoTThingTemperatureHumiditySensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.png) | ![illustration for AwsIoTThingTemperatureHumiditySensor](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor.Local.png) | ![illustration for AwsIoTThingTemperatureHumiditySensorCard](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensorCard.Local.png) | ![illustration for AwsIoTThingTemperatureHumiditySensorGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensorGroup.Local.png) |




## AwsIoTThingTemperatureHumiditySensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensor
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensor('AwsIoTThingTemperatureHumiditySensor', 'Aws Io T Thing Temperature Humidity Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensor
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensor('AwsIoTThingTemperatureHumiditySensor', 'Aws Io T Thing Temperature Humidity Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingTemperatureHumiditySensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorCard('AwsIoTThingTemperatureHumiditySensorCard', 'Aws Io T Thing Temperature Humidity Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorCard('AwsIoTThingTemperatureHumiditySensorCard', 'Aws Io T Thing Temperature Humidity Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingTemperatureHumiditySensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorGroup('AwsIoTThingTemperatureHumiditySensorGroup', 'Aws Io T Thing Temperature Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureHumiditySensorGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingTemperatureHumiditySensor')

' renders the element
AwsIoTThingTemperatureHumiditySensorGroup('AwsIoTThingTemperatureHumiditySensorGroup', 'Aws Io T Thing Temperature Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
